import { Plugin } from "@webiny/plugins";
export interface CompressedValue {
    compression: string;
    content: string | null;
}
/**
 * Functions that are using compress and decompress methods have try/catch around them.
 * canDecompress only expects boolean, no try/catch around it.
 */
export declare abstract class ContentCompressionPlugin extends Plugin {
    static readonly type: string;
    readonly identifier: string;
    protected constructor(identifier: string);
    /**
     * Must return true if it is possible to compress the content with given implementation.
     */
    abstract canCompress(value: any): boolean;
    /**
     * Must return if it is possible to decompress the content with given implementation.
     * This step makes sure no invalid data is passed into decompress method.
     */
    abstract canDecompress(value: CompressedValue): boolean;
    /**
     * Compress the content and return the CompressedValue object.
     * @throws
     */
    abstract compress(value: any): Promise<CompressedValue>;
    /**
     * Decompress the content if possible. No need to check if given compressed value can be decompressed with given implementation.
     * It is done in the canDecompress step.
     * @throws
     */
    abstract decompress(value: CompressedValue): Promise<any>;
}
